@@ -1,12 +1,27 @@
 
 test_that("GKIndex produces the right answer for CES_sigma_2", {
 
+  # inverse method of solving
   expect_equal(GKIndex(CES_sigma_2,
                        pvar = "prices",
                        qvar = "quantities",
                        prodID = "prodID",
                        pervar = "time",
-                       window = 12),
+                       window = 12,
+                       solveMethod = "inverse"),
+               as.matrix(c(1, 0.87763982, 1.14963977, 1.20948388,
+                           0.97735333, 1.30228207, 1.23643987,
+                           1.00131376, 1.20675381, 0.98419301,
+                           1.23476104, 1.23245315)))
+
+  # iterative method of solving
+  expect_equal(GKIndex(CES_sigma_2,
+                       pvar = "prices",
+                       qvar = "quantities",
+                       prodID = "prodID",
+                       pervar = "time",
+                       window = 12,
+                       solveMethod = "iterative"),
                as.matrix(c(1, 0.87763982, 1.14963977, 1.20948388,
                            0.97735333, 1.30228207, 1.23643987,
                            1.00131376, 1.20675381, 0.98419301,
@@ -104,3 +119,36 @@ test_that("GKIndex produces the right answer for different splices", {
                            1.19801321479787, 0.975391622972356, 1.22318540412509, 1.23044626729226)))
 
 })
+
+test_that("The right GKIndex result is given when prices are imputed", {
+
+  df <- CES_sigma_2[-c(2:3),]
+  result <- GKIndex(df, pvar = "prices", qvar = "quantities", pervar = "time",
+                       prodID = "prodID", imputePrices = "carry", window = 12)
+
+  expect_equal(result, as.matrix(c(1, 0.845456231499799, 1.12667552753356, 1.21307301784934,
+                                   0.979935919797748, 1.30823790438779, 1.24195298875981, 1.00350594026418,
+                                   1.21305477610043, 0.988593091923226, 1.24335349326667, 1.24219039245365
+  )))
+
+})
+
+
+test_that("Error is thrown for wrong splice method", {
+
+  expect_error(GKIndex(CES_sigma_2,pvar = "prices",qvar = "quantities",
+                         pervar = "time", prodID = "prodID",
+                         sample = "matched", window = 12, splice = "wrongSplice"),
+               "Not a valid splicing method.")
+
+})
+
+test_that("Error is thrown for wrong imputePrices parameter", {
+
+  expect_error(GEKSIndex(CES_sigma_2,pvar = "prices",qvar = "quantities",
+                         pervar = "time", prodID = "prodID",
+                         sample = "matched", window = 12, splice = "window", imputePrices = "wrongImpute"),
+               "Invalid imputePrices argument")
+
+})
+
